@@ -51,7 +51,7 @@ PositionEditWidget::PositionEditWidget(std::shared_ptr<AssetParameterModel> mode
     connect(m_slider, &QAbstractSlider::valueChanged, this, &PositionEditWidget::valueChanged);
 
     // emit the signal of the base class when appropriate
-    connect(this->m_slider, &QAbstractSlider::valueChanged, [this](int val) {
+    connect(this->m_slider, &QAbstractSlider::valueChanged, this, [this](int val) {
         if (m_inverted) {
             val = m_model->data(m_index, AssetParameterModel::ParentInRole).toInt() + m_model->data(m_index, AssetParameterModel::ParentDurationRole).toInt() - 1 -
                   val;
