@@ -662,6 +662,9 @@ public:
     /** @brief Returns a list of all luma files used in the project
      */
     QStringList extractCompositionLumas() const;
+    /** @brief Returns a list of all external files used by effects in the timeline
+     */
+    QStringList extractExternalEffectFiles() const;
     /** @brief Inform asset view of duration change
      */
     virtual void adjustAssetRange(int clipId, int in, int out);
