@@ -47,7 +47,7 @@ void MixStackView::setModel(const std::shared_ptr<AssetParameterModel> &model, Q
     }
     connect(this, &AssetParameterView::seekToPos, [this](int pos) {
         // at this point, the effects returns a pos relative to the clip. We need to convert it to a global time
-        int clipIn = pCore->getItemPosition(m_model->getOwnerId());
+        int clipIn = 0; //pCore->getItemPosition(m_model->getOwnerId());
         emit seekToTransPos(pos + clipIn);
     });
     emit initKeyframeView(true);
